@@ -382,6 +382,84 @@ class ICF(object):
                                       'icf': '(elem_abun["PTPR92_21"] / abun["He2"])**2',
                                       'type': 'PNe',
                                       'comment': 'Based on photoionization models'},
+                         
+                         
+                         'DIMS14_10': {'elem': 'He',
+                                       'atom':'abun["He2"] + abun["He3"]', 
+                                       'icf': '1.0',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_12': {'elem': 'O',
+                                       'atom':'abun["O2"] + abun["O3"]', 
+                                       'icf': '10**((0.08 * abun["He3"] / (abun["He2"] + abun["He3"]) + 0.006 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2) / (0.34 - 0.27 * abun["He3"] / (abun["He2"] + abun["He3"])))',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_14': {'elem': 'N',
+                                       'atom':'abun["N2"]', 
+                                       'icf': '10**(-0.16 * abun["O3"] / (abun["O2"] + abun["O3"]) * (1.0 + np.log10(abun["He3"] / (abun["He2"] + abun["He3"])))) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_14b': {'elem': 'N',
+                                       'atom':'abun["N2"]', 
+                                       'icf': '10**(0.64 * abun["O3"] / (abun["O2"] + abun["O3"])) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_17a': {'elem': 'Ne',
+                                       'atom':'abun["Ne3"]', 
+                                       'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (abun["He3"] / (abun["He2"] + abun["He3"])) + 2 * (abun["He3"] / (abun["He2"] + abun["He3"]))**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_17b': {'elem': 'Ne',
+                                       'atom':'abun["Ne3"]', 
+                                       'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (0.01) + 2 * (0.01)**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_17c': {'elem': 'Ne',
+                                       'atom':'abun["Ne3"]', 
+                                       'icf': '(abun["O3"] / (abun["O2"] + abun["O3"]) + (0.014 / (0.015) + 2 * (0.015)**2.7)**3 * (0.7 + 0.2 * abun["O3"] / (abun["O2"] + abun["O3"]) - 0.8 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2)) * elem_abun["DIMS14_12"] / abun["O3"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_23': {'elem': 'S',
+                                       'atom':'abun["S2"]', 
+                                       'icf': '(10**(0.31 - 0.52 * abun["He3"] / (abun["He2"] + abun["He3"]))) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_26': {'elem': 'S',
+                                       'atom':'abun["S2"] + abun["S3"]', 
+                                       'icf': '(10**((-0.02 - 0.03*abun["O3"] / (abun["O2"] + abun["O3"]) - 2.31*(abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 2.19 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) / (0.69 + 2.09 * abun["O3"] / (abun["O2"] + abun["O3"]) - 2.69 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2))) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_29': {'elem': 'Cl',
+                                       'atom':'abun["Cl3"]', 
+                                       'icf': '((4.162 - 4.1622*(abun["O3"] / (abun["O2"] + abun["O3"]))**0.21)**.75) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_29b': {'elem': 'Cl',
+                                       'atom':'abun["Cl2"] + abun["Cl3"]', 
+                                       'icf': '(1.) * elem_abun["DIMS14_12"] / abun["O2"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_32': {'elem': 'Cl',
+                                       'atom':'abun["Cl2"] + abun["Cl3"] + abun["Cl4"]', 
+                                       'icf': '0.98 + (0.56 - 0.57 * abun["He3"] / (abun["He2"] + abun["He3"]))**7.64',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_35': {'elem': 'Ar',
+                                       'atom':'abun["Ar3"]', 
+                                       'icf': '(10**(0.05 / (0.06 + abun["O3"] / (abun["O2"] + abun["O3"])) - 0.07)) * elem_abun["DIMS14_12"] / (abun["O2"] + abun["O3"])',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_36': {'elem': 'Ar',
+                                       'atom':'abun["Ar3"]', 
+                                       'icf': '(10**((0.03  * abun["O3"] / (abun["O2"] + abun["O3"])) / (0.4 - 0.3 * abun["O3"] / (abun["O2"] + abun["O3"])) - 0.05)) * elem_abun["DIMS14_12"] / (abun["O2"] + abun["O3"])',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         'DIMS14_39': {'elem': 'C',
+                                       'atom':'abun["C3"]', 
+                                       'icf': '(0.05 + 2.21 * abun["O3"] / (abun["O2"] + abun["O3"]) - 2.77 * (abun["O3"] / (abun["O2"] + abun["O3"]))**2 + 1.74 * (abun["O3"] / (abun["O2"] + abun["O3"]))**3) * elem_abun["DIMS14_12"] / abun["O3"]',
+                                       'type': 'PNe',
+                                       'comment': 'Based on photoionization models'},
+                         
                          }
         
         Ial06 = [('18a', 'N', 'N2', (-0.825, 0.718, 0.853), 'v', 'low Z'),
@@ -446,7 +524,9 @@ class ICF(object):
 #                             'G07': {'ref': 'Girard, Koeppen and Acker 2007, A&A, 463, 265',
 #                                      'url': 'http://adsabs.harvard.edu/abs/2007A%26A...463..265G'},
                               'PTPR92': {'ref': 'Peimbert et al 1992, RMAA, 24, 155',
-                                        'url': 'http://adsabs.harvard.edu/abs/1992RMxAA..24..155P'}
+                                        'url': 'http://adsabs.harvard.edu/abs/1992RMxAA..24..155P'},
+                             'DIMS14': {'ref': 'Delgado-Inglada et al., 2014, MNRAS',
+                                        'url':'http://arxiv.org/abs/1402.4852'}
                              }
 
     def _calcIal06(self, coeff, degree):
