@@ -8,6 +8,7 @@ import string
 if pn.config.INSTALLED['plt']:
     import matplotlib as mpl
     import matplotlib.pyplot as plt
+    import matplotlib.ticker
     from matplotlib.ticker import MaxNLocator
 
 from pyneb.utils.misc import int_to_roman
@@ -67,7 +68,7 @@ class DataPlot(object):
             self.ref_tem = ref_tem
 
         # Atom
-        self.elem = elem
+        self.elem = str.capitalize(elem)
         self.spec = spec
         # n_max = max value of NLevels. Used to format the collision strength plot.
         self.atom_n_max = 0
@@ -160,6 +161,72 @@ class DataPlot(object):
             plt.savefig(self.atom + '_' + data['ID'] + "-" + self.ref_data + "_A.pdf")
 
 
+
+    def plotAllA(self, save=False, figsize=[18, 12], fignum=None):
+        """
+        Plot the log of the A values of each data set 
+        
+        Parameters:
+            - save     if True, saves the plot in a file
+            - figsize  figure size (default: [18, 12])
+            - fignum    figure Number
+
+        """
+        if not pn.config.INSTALLED['plt']:
+            pn.log_.error('Matplotlib not installed!', calling=self.calling)
+        fig = plt.figure(fignum)
+        plt.clf()
+        max_y_ticks = 6
+        ticks = range(len(self.atom_data)+1)[1:] 
+        
+        A = np.zeros([len(self.atom_data), self.atom_n_max, self.atom_n_max])
+        color=[]
+        for i, data in enumerate(self.atom_data):
+            A[i, :] = data['atom'].getA()
+            color.append(data['color'])
+        
+        A[np.where((A<=0))] = np.NaN
+        lgA = np.log10(A)
+
+        for j in range(2, self.atom_n_max+1):
+            for i in range(1, j):
+                x = ticks
+                y = lgA[:, j-1, i-1]
+                ax = plt.subplot(self.atom_n_max - 1, self.atom_n_max - 1, (self.atom_n_max-1)*(j-2) + i,
+                                 axisbg='#FFFFE0')
+                ax.set_xticks(x)
+                plt.xlim((min(x)-0.5, max(x)+0.5))
+                if ((j == self.atom_n_max) and (i == 1)):
+                    plt.xlabel('Reference #', fontsize=8)
+                    plt.ylabel('Log(A$_{ji}$)', fontsize=8)
+                ax.yaxis.set_major_locator(MaxNLocator(max_y_ticks-1))
+                plt.tight_layout(pad=0.1)
+                plt.subplots_adjust(left=0.15, right=0.95, top=0.95, bottom=0.12)
+                plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
+                plt.draw()
+                try:
+                    plt.scatter(x, y, color=color, label='_nolegend_')
+                    lbl = "(" + str(j) + r"$\to$" + str(i) + ")"
+                    ax.text(0.95, 0.95, lbl, fontsize=10, color="#660066", transform=ax.transAxes, ha="right", va="top")                                    
+                except:
+                    pn.log_.warn('Problem with plotting a subplot', calling=self.calling)
+
+        fig.text(.5, .05, "i (lower level)", fontsize=12, ha='center', color="#660066", va='top')
+        fig.text(.05, .5, "j (upper level)", ha='left', va='center', fontsize=12, color="#660066", rotation=90)
+        title = "Available transition probabilities for {0} {1}".format(self.elem, int_to_roman(int(self.spec)))
+        fig.text(.5, .95, title, color="#191970", fontsize=14, ha='center')
+        for i, data in enumerate(self.atom_data):
+            x_txt = .95
+            y_txt = .85 - .04*i 
+            fig.text(x_txt, y_txt, "Ref. %d: %s" %(i+1, data['ID']), color=color[i], ha = 'right') 
+
+        if save:
+            plt.figure(figsize=[18, 12])
+            plt.savefig(self.atom + "_all_As.pdf")
+    
+        plt.show()      
+        
+
     def plotRelA(self, ref_data=None, save=False, figsize=[18, 12], fignum=None):
         """
         Plot the relative difference of the A of each data set with respect to the reference one
@@ -299,7 +366,7 @@ class DataPlot(object):
                         ax = plt.subplot(self.coll_n_max - 1, self.coll_n_max - 1, (self.coll_n_max - 1) * (j - 2) + i,
                                          axisbg='#FFFFE0')
                         try:
-                            ax.plot((np.log10(tem_points)), data['atom'].getOmegaArray(j, i), color=data['color'],
+                            ax.plot((np.log10(tem_points)), data['atom'].getOmega(tem_points,j, i), color=data['color'],
                                     marker='o', linestyle='None', label='_nolegend_')
                         except:
                             pn.log_.warn('Problem with plotting a data set', calling=self.calling)
@@ -307,7 +374,7 @@ class DataPlot(object):
                         if scan_orders is None:
                             try:
                                 ax.plot((np.log10(tem_funct)), data['atom'].getOmega(tem_funct, j, i),
-                                        color=data['color'], label='_nolegend_')
+                                         label='_nolegend_')
                             except:
                                 pn.log_.warn('Problem with plotting a data set', calling=self.calling)
                         else:
