@@ -14,6 +14,7 @@ class _ManageAtomicData(object):
         self.setDataFileDict()
         self.addDataFilePath()
         self.addDataFilePath('../atomic_data_fits/', inPyNeb=True)
+        self.addDataFilePath('../atomic_data/', inPyNeb=True)
         self.addDataFilePath('./')
         self._RecombData = {}
         self.plot_path = execution_path('../plot/level_diagrams/')
@@ -269,7 +270,7 @@ class _ManageAtomicData(object):
                     del self._RecombData[atom]
             self.log_.message('Adding {0} {1} data for {2}'.format(data_file, data_type, atom), calling=self.calling)
         else:
-            self.log_.warn('File path of {0} not included in list. Run addDataFilePath first'.format(data_file),
+            self.log_.warn('Unknown file or File path of {0} not included in list. Run addDataFilePath first'.format(data_file),
                            calling=self.calling)
         if (atom == 'H1') and ('H1' in pn.atomicData._RecombData):
             del pn.atomicData._RecombData['H1']
