@@ -1,4 +1,5 @@
 from math import sqrt
+import numpy as np
 
 class CST(object):
     BOLTZMANN = 1.3806488e-16 # erg/K - NIST 2010
@@ -222,3 +223,63 @@ _predefinedDataFileDict = {'IRAF_09':
                              'Xe4': {'atom': 'xe_iv_atom_S04-BHQZ95.fits', 'coll': 'xe_iv_coll_SB98.fits'}
                              }
                            } 
+
+def air_to_vacuum(airwl,nouvconv=True):
+    """
+    Returns vacuum wavelength of the provided air wavelength array or scalar.
+    Good to ~ .0005 angstroms.
+
+    If nouvconv is True, does nothing for air wavelength < 2000 angstroms.
+    
+    Input must be in angstroms.
+    
+    Adapted from idlutils airtovac.pro, based on the IAU standard 
+    for conversion in Morton (1991 Ap.J. Suppl. 77, 119)
+    Taken from astropysics.spec
+    """
+    airwl = np.array(airwl,copy=False,dtype=float,ndmin=1)
+    isscal = airwl.shape == tuple()
+    if isscal:
+        airwl = airwl.ravel()
+    
+    #wavenumber squared
+    sig2 = (1e4/airwl)**2
+    
+    convfact = 1. + 6.4328e-5 + 2.94981e-2/(146. - sig2) +  2.5540e-4/( 41. - sig2)
+    newwl = airwl.copy() 
+    if nouvconv:
+        convmask = newwl>=2000
+        newwl[convmask] *= convfact[convmask]
+    else:
+        newwl[:] *= convfact
+    return newwl[0] if isscal else newwl
+
+def vacuum_to_air(vacwl,nouvconv=True):
+    """
+    Returns air wavelength of the provided vacuum wavelength array or scalar.
+    Good to ~ .0005 angstroms.
+    
+    If nouvconv is True, does nothing for air wavelength < 2000 angstroms.
+    
+    Input must be in angstroms.
+    
+    Adapted from idlutils vactoair.pro.
+    Taken from astropysics.spec
+    """
+    vacwl = np.array(vacwl,copy=False,dtype=float)
+    isscal = vacwl.shape == tuple()
+    if isscal:
+        vacwl = vacwl.ravel()
+    
+    #wavenumber squared
+    wave2 = vacwl*vacwl
+    
+    convfact = 1.0 + 2.735182e-4 + 131.4182/wave2 + 2.76249e8/(wave2*wave2)
+    newwl = vacwl.copy()/convfact
+    
+    if nouvconv:    
+        #revert back those for which air < 2000
+        noconvmask = newwl<2000
+        newwl[noconvmask] *= convfact[noconvmask] 
+    
+    return newwl[0] if isscal else newwl
